@@ -12,6 +12,8 @@ class InboxRegistration:
         'clickwrap_body': None,     # string - Clickwrap text that was shown to the registrant
         'form_field_set_id': None,     # int64 - Id of associated form field set
         'form_field_data': None,     # string - Data for form field set with form field ids as keys and user data as values
+        'inbox_id': None,     # int64 - Id of associated inbox
+        'inbox_recipient_id': None,     # int64 - Id of associated inbox recipient
     }
 
     def __init__(self, attributes=None, options=None):
@@ -33,7 +35,7 @@ class InboxRegistration:
 # Parameters:
 #   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
-#   folder_behavior_id (required) - int64 - ID of the associated Inbox.
+#   folder_behavior_id - int64 - ID of the associated Inbox.
 def list(params = None, options = None):
     if not isinstance(params, dict):
         params = {}
@@ -45,8 +47,6 @@ def list(params = None, options = None):
         raise InvalidParameterError("Bad parameter: per_page must be an int")
     if "folder_behavior_id" in params and not isinstance(params["folder_behavior_id"], int):
         raise InvalidParameterError("Bad parameter: folder_behavior_id must be an int")
-    if "folder_behavior_id" not in params:
-        raise MissingParameterError("Parameter missing: folder_behavior_id")
     return ListObj(InboxRegistration,"GET", "/inbox_registrations", params, options)
 
 def all(params = None, options = None):
